United States Court of International Trade

| Welcome to the website of the United States Court of International Trade | A-Z Index Help | Advanced
Home About The Court CM/ECF Rules & Forms Judges Judges Judicial Ethics Opinions & Orders Slip Opinions Daily Disposition Sheet Attorney Info Trade Adjustment Assistance

Slip Opinions
Note: The Court works to ensure the timeliness and accuracy of this information. However, researchers should independently verify the status of the opinions as well as their precedential value and note that the slip opinions filed on the Court's CM/ECF system are the official court documents of record.
Having trouble viewing PDF documents?
2014
2013
2012
2011
2010
2009
2008
2007
2006
2005
2004
2003
2002
2001
2000
1999
Number | Caption | Date | Court No. | Judge | Jurisdiction
--- | --- | --- | --- | --- | ---
14-90 | JBF Rak LLC v. United States | 07/30/2014 | 12-00099 | Barzilay | 1581(c)
14-89 | Papierfabrik August Koehler SE v. United States | 07/28/2014 | 13-00163 | Tsoucalas | 1581(c)
14-88 | Clearon Corp. v. United States | 07/24/2014 | Consol. 13-00073 | Musgrave | 1581(c)
14-87 | Navneet Publ'ns (India) Ltd. v. United States Public version posted 08/04/2014. | 07/22/2014 | 13-00204 | Goldberg | 1581(c)
14-86 | Dupont Teijin Films v. United States | 07/22/2014 | 12-00088 | Restani | 1581(c)
14-85 | Golden Dragon Precise Copper Tube Grp., Inc. v. United States | 07/18/2014 | Consol. 14-00116 | Musgrave | 1581(c)(i)
14-84 | Cerro Flow Prods., LLC v. United States Public version posted 07/18/2014. | 07/18/2014 | 13-00237 | Restani | 1581(c)
14-83 | Dongguan Sunrise Furniture Co., Ltd. v. United States Public version posted 07/18/2014. | 07/18/2014 | 10-00254 | Restani | 1581(c)
14-82 | Swiff-Train Co. v. United States | 07/16/2014 | 12-00010 | Musgrave | 1581(c)
14-81 | Changzhou Hawd Flooring, Co. v. United States | 07/14/2014 | 12-00020 | Pogue | 1581(c)
14-80 | Puerto Rico Towing & Barge Co. v. United States | 07/10/2014 | 11-00438 | Restani | 1581(a)
14-79 | Gold East Paper (Jiangsu) Co. v. United States Errata: 07/09/2014. | 07/02/2014 | Consol. 10-00371 | Musgrave | 1581(c)
14-78 | JBF RAK LLC v. United States | 07/01/2014 | 13-00211 | Barzilay | 1581(c)
14-77 | Standard Furniture Mfg. Co., Inc. v. United States | 06/27/2014 | 13-00202 | Stanceu | 1581(i)
14-76 | Ethan Allen Global, Inc. v. United States | 06/27/2014 | 13-00183 | Stanceu | 1581(i)
14-75 | Vietnam Ass'n of Seafood Exps. & Producers v. United States | 06/26/2014 | 14-00115 | Kelly | 1581(c)
14-74 | Int'l Custom Prods., Inc. v. United States | 06/26/2014 | 08-00189 | Carman | 1581(a)(i)
14-73 | Zhanjiang Guolian Aquatic Prods. Co. v. United States | 06/26/2014 | 13-00388 | Carman | 1581(c)
14-72 | Mid Continent Nail Corp. v. United States Public version posted 07/22/2014. | 06/26/2014 | Consol. 12-00133 | Carman | 1581(c)
14-71 | Borusan Mannesmann Boru Sanayi Ve Ticaret A.S. v. United States | 06/25/2014 | 13-00001 | Barzilay | 1581(c)
14-70 | Jacobi Carbons AB v. United States | 06/24/2014 | Consol. 12-00365 | Eaton | 1581(c)
14-69 | Foshan Shunde Yongjian Housewares & Hardware Co. v. United States Public version posted 06/30/2014. | 06/20/2014 | 10-00059 | Eaton | 1581(c)
14-68 | Since Hardware (Guangzhou) Co. v. United States | 06/18/2014 | Consol. 11-00106 | Gordon | 1581(c)
14-67 | Ashley Furniture Indus., Inc. v. United States | 06/17/2014 | 13-00201 | Stanceu | 1581(i)
14-66 | Siemens Energy, Inc. v. United States Public version posted 07/07/2014. | 06/17/2014 | Consol. 13-00104 | Barnett | 1581(c)
14-65 | Ford Motor Co. v. United States | 06/17/2014 | 09-00151 | Barnett | 1581(i)
14-64 | JTEKT Corp. v. United States | 06/11/2014 | Consol. 08-00324 | Stanceu | 1581(c)
14-63 | Tianjin Magnesium Int’l Co. v. United States | 06/11/2014 | Consol. 11-00006 | Eaton | 1581(c)
14-62 | Peer Bearing Co.-Changshan v. United States | 06/10/2014 | Consol. 11-00022 | Stanceu | 1581(c)
14-61 | Borusan Mannesmann Boru Sanayi Ve Ticaret A.S. v. United States | 06/06/2014 | 14-00129 | Kelly | 1581(i)
14-60 | Changzhou Hawd Flooring Co. v. United States | 05/29/2014 | 12-00020 | Pogue | 1581(c)
14-59 | Ad Hoc Shrimp Trade Action Comm. v. United States | 05/29/2014 | 12-00314 | Pogue | 1581(c)
14-58 | Fischer S.A. Comercio, Industria and Agricultura v. United States Public version posted 06/23/2014. | 05/27/2014 | 12-00340 | Goldberg | 1581(c)
14-57 | Ad Hoc Shrimp Trade Action Comm. v. United States Public version posted 06/30/2014. | 05/27/2014 | 12-00290 | Pogue | 1581(c)
14-56 | Blink Design, Inc. v. United States Errata: 05/27/2014. | 05/21/2014 | 14-00032 | Barnett | 1581(a)
14-55 | Ad Hoc Shrimp Trade Action Comm. v. United States Public version posted 06/30/2014. | 05/20/2014 | 10-00275 11-00335 | Pogue | 1581(c)
14-54 | LDA Incorporado v. United States | 05/13/2014 | 12-00349 | Kelly | 1581(a)
14-53 | Ford Motor Co. v. United States | 05/09/2014 | 03-00115 | Barzilay | 1581(a)
14-52 | Artisan Mfg. Corp. v. United States | 05/05/2014 | 13-00169 | Stanceu | 1581(c)
14-51 | Timken Co. v. United States | 05/02/2014 | Consol. 13-00069 | Restani | 1581(c)
14-50 | Diamond Sawblades Mfrs.' Coal. v. United States | 04/29/2014 | 13-00078 | Musgrave | 1581(c)
14-49 | Wheatland Tube Co. v. United States | 04/29/2014 | 12-00189 | Musgrave | 1581(c)
14-48 | BP Oil Supply Co. v. United States | 04/29/2014 | 04-00321 | Barnett | 1581(a)
14-47 | Royal Thai Gov't v. United States | 04/23/2014 | 13-00333 | Restani | 1581(c)
14-46 | Thai Union Frozen Prods. Pub. Co. v. United States | 04/23/2014 | 13-00330 | Restani | 1581(c)
14-45 | Shenzhen Xinboda Indus. Co. v. United States | 04/16/2014 | 11-00267 | Ridgway | 1581(c)
14-44 | Since Hardware (Guangzhou) Co. v. United States Errata: 06/19/2014. | 04/15/2014 | Consol. 11-00106 | Gordon | 1581(c)
14-43 | Hubscher Ribbon Corp. v. United States Public version posted 04/25/2014. | 04/15/2014 | 13-00071 | Gordon | 1581(c)
14-42 | CP Kelco Oy v. United States Public version posted 04/30/2014. | 04/15/2014 | 13-00079 | Goldberg | 1581(c)
14-41 | Diamond Sawblades Mfrs.' Coal. v. United States | 04/14/2014 | 13-00391 | Eaton | 1581(i)
14-40 | Florida Tomato Exch. v. United States | 04/11/2014 | 13-00148 | Eaton | 1581(c)
14-39 | Samsung Elecs. Co. v. United States Public version posted 04/11/2014. | 04/11/2014 | 13-00099 | Tsoucalas | 1581(c)
14-38 | Yantai Xinke Steel Structure Co. v. United States | 04/09/2014 | 10-00240 | Eaton | 1581(c)
14-37 | Itochu Bldg. Prods. v. United States | 04/08/2014 | 11-00208 | Stanceu | 1581(c)
14-36 | FDK America, Inc. v. United States | 04/04/2014 | 11-000385 | Musgrave | 1581(a)
14-35 | Baroque Timber Indus. (Zhongshan) Co. v. United States | 03/31/2014 | Consol. 12-00007 | Pogue | 1581(c)
14-34 | Jinan Yipin Corp. v. United States | 03/28/2014 | 06-00189 | Ridgway | 1581(c)
14-33 | CS Wind Vietnam Co. v. United States | 03/27/2014 | 13-00102 | Restani | 1581(c)
14-32 | Meridian Prods. LLC v. United States | 03/26/2014 | 13-00018 | Musgrave | 1581(c)
14-31 | Papierfabrik August Koehler AG v. United States | 03/25/2014 | 11-00147 | Stanceu | 1581(c)
14-30 | Dongtai Peak Honey Indus. Co. v. United States | 03/21/2014 | 12-00411 | Tsoucalas | 1581(c)
14-29 | Diamond Sawblades Mfrs.' Coal. v. United States | 03/13/2014 | 13-00391 | Eaton | 1581(i)
14-28 | Camau Frozen Seafood Processing Imp. Exp. Corp. v. United States | 03/10/2014 | Consol. 11-00399 | Pogue | 1581(c)
14-27 | Union Steel Mfg. Co. v. United States | 03/04/2014 | Consol. 10-00106 | Stanceu | 1581(c)
14-26 | Atar S.r.l. v. United States | 03/03/2014 | 07-00086 | Stanceu | 1581(c)
14-25 | Changzhou Wujin Fine Chem. Factory Co. v. United States | 02/28/2014 | Consol. 09-00216 | Barzilay | 1581(c)
14-24 | Timken Co. v. United States | 02/27/2014 | Consol. 12-00415 | Restani | 1581(c)
14-23 | Downhole Pipe & Equip., LP v. United States | 02/25/2014 | 11-00080 | Stanceu | 1581(c)
14-22 | Best Key Textiles Co. v. United States | 02/25/2014 | 13-00367 | Musgrave | 1581(h) & 1581(i)
14-21 | Archer Daniels Midland Co. v. United States Public version posted 02/26/2014. | 02/24/2014 | Consol. 11-00537 | Barzilay | 1581(c)
14-20 | Meridian Prods. LLC v. United States | 02/19/2014 | 13-00246 | Stanceu | 1581(c)
14-19 | Zhaoqing New Zhongya Aluminum Co. v. United States | 02/19/2014 | 11-00181 | Pogue | 1581(c)
14-18 | Beihai Zhengwu Indus. Co., Ltd. v. United States | 02/18/2014 | 05-00182 | Stanceu | 1581(c)
14-17 | Xinjiamei Furniture (Zhangzhou) Co., Ltd. v. United States | 02/18/2014 | 11-00456 | Eaton | 1581(c)
14-16 | Netchem, Inc. v. United States | 02/14/2014 | 12-00123 | Goldberg | 1581(a)
14-15 | Peer Bearing Co.-Changshan v. United States | 02/13/2014 | Consol. 10-00013 | Stanceu | 1581(c)
14-14 | Tianjin Wanhua Co., Ltd. v. United States | 02/12/2014 | Consol. 12-00095 | Restani | 1581(c)
14-13 | JTEKT Corp. v. United States | 02/10/2014 | Consol. 06-00250 | Stanceu | 1581(c)
14-12 | Jiaxing Brother Fastener Co., Ltd. v. United States | 02/06/2014 | 12-00384 | Gordon | 1581(c)
14-11 | Trade Associates Group, Ltd. v. United States | 01/31/2014 | 11-00397 | Stanceu | 1581(c)
14-10 | Shenyang Yuanda Alum. Indus. Eng'g Co. v. United States | 01/30/2014 | Consol. 12-00420 | Eaton | 1581(c)
14-09 | Medline Industries, Inc. v. United States | 01/29/2014 | 13-00070 | Tsoucalas | 1581(c)
14-08 | LG Electronics, Inc. v. United States Int'l Trade Comm'n | 01/23/2014 | Consol. 13-00100 | Kelly | 1581(c)
14-07 | United States v. American Home Assurance Co. | 01/23/2014 | 10-00185 | Goldberg | 1582(2)
14-06 | Aluminum Extrusions Fair Trade Comm. v. United States | 01/23/2014 | Consol. 11-00216 | Pogue | 1581(c)
14-05 | Macclenny Prods. v. United States Errata: 02/25/2014. Errata: 02/21/2014. | 01/22/2014 | 05-00484 | Ridgway | 1581(a)
14-04 | Changshan Peer Bearing Co. v. United States | 01/15/2014 | 12-00039 | Stanceu | 1581(c)
14-03 | United States v. Lafidale, Inc. | 01/10/2014 | 12-00397 | Restani | 1582
14-02 | JBF RAK LLC v. United States Public version posted 01/22/2014. | 01/08/2014 | 11-00141 | Barzilay | 1581(c)
14-01 | Papierfabrik August Koehler SE v. United States | 01/06/2014 | 13-00163 | Tsoucalas | 1581(c)

Feedback Last modified August 4, 2014